diff --git a/module/VuFind/src/VuFind/ILS/Logic/Holds.php b/module/VuFind/src/VuFind/ILS/Logic/Holds.php
index b7c44d5dfc7969c6c7f89d5e433835d7d564af61..543ba0180f789933ae76b9e36412a38fb8cda930 100644
--- a/module/VuFind/src/VuFind/ILS/Logic/Holds.php
+++ b/module/VuFind/src/VuFind/ILS/Logic/Holds.php
@@ -28,7 +28,6 @@
  */
 namespace VuFind\ILS\Logic;
 use VuFind\Config\Reader as ConfigReader,
-    VuFind\Connection\Manager as ConnectionManager,
     VuFind\Crypt\HMAC,
     VuFind\ILS\Connection as ILSConnection;
 
@@ -55,7 +54,7 @@ class Holds
      * @param \VuFind\Auth\Manager $account Auth manager object
      * @param ILSConnection        $catalog A catalog connection
      */
-    public function __construct($account, $catalog = false)
+    public function __construct($account, $catalog)
     {
         $this->account = $account;
         $this->config = ConfigReader::getConfig();
@@ -66,8 +65,7 @@ class Holds
             }
         }
 
-        $this->catalog = ($catalog !== false)
-            ? $catalog : ConnectionManager::connectToCatalog();
+        $this->catalog = $catalog;
     }
 
     /**
diff --git a/module/VuFind/src/VuFind/ILS/Logic/TitleHolds.php b/module/VuFind/src/VuFind/ILS/Logic/TitleHolds.php
index 7e80187635ffca6f285ebd1815df95a4fb5af933..103ccc2e0ac2e3edb2390c2bdfef68390e42ec14 100644
--- a/module/VuFind/src/VuFind/ILS/Logic/TitleHolds.php
+++ b/module/VuFind/src/VuFind/ILS/Logic/TitleHolds.php
@@ -28,7 +28,6 @@
  */
 namespace VuFind\ILS\Logic;
 use VuFind\Config\Reader as ConfigReader,
-    VuFind\Connection\Manager as ConnectionManager,
     VuFind\Crypt\HMAC,
     VuFind\ILS\Connection as ILSConnection;
 
@@ -55,7 +54,7 @@ class TitleHolds
      * @param \VuFind\Auth\Manager $account Auth manager object
      * @param ILSConnection        $catalog A catalog connection
      */
-    public function __construct($account, $catalog = false)
+    public function __construct($account, $catalog)
     {
         $this->account = $account;
         $this->config = ConfigReader::getConfig();
@@ -66,8 +65,7 @@ class TitleHolds
             }
         }
 
-        $this->catalog = ($catalog !== false)
-            ? $catalog : ConnectionManager::connectToCatalog();
+        $this->catalog = $catalog;
     }
 
     /**
diff --git a/module/VuFind/src/VuFind/RecordDriver/SolrMarc.php b/module/VuFind/src/VuFind/RecordDriver/SolrMarc.php
index a0ea58cb5b57ed1b812532bc690ff82b53a1d5bb..c3151ebb0aab25bfc2df49df500d692976685632 100644
--- a/module/VuFind/src/VuFind/RecordDriver/SolrMarc.php
+++ b/module/VuFind/src/VuFind/RecordDriver/SolrMarc.php
@@ -797,7 +797,7 @@ class SolrMarc extends SolrDefault
      */
     public function getRealTimeHoldings($account)
     {
-        $holdLogic = new HoldLogic($account);
+        $holdLogic = new HoldLogic($account, ConnectionManager::connectToCatalog());
         return $holdLogic->getHoldings($this->getUniqueID());
     }
 
@@ -833,7 +833,9 @@ class SolrMarc extends SolrDefault
             || stristr("part", $biblioLevel)
         ) {
             if (ILSConnection::getTitleHoldsMode() != "disabled") {
-                $holdLogic = new TitleHoldLogic($account);
+                $holdLogic = new TitleHoldLogic(
+                    $account, ConnectionManager::connectToCatalog()
+                );
                 return $holdLogic->getHold($this->getUniqueID());
             }
         }
diff --git a/module/VuFind/src/VuFind/Controller/AjaxController.php b/module/VuFind/src/VuFind/Controller/AjaxController.php
index 62ed914957f3ec42f9e36e0c85dbb8613a4d9582..fe9a13d331685d707532611fbf9e1929effb9053 100644
--- a/module/VuFind/src/VuFind/Controller/AjaxController.php
+++ b/module/VuFind/src/VuFind/Controller/AjaxController.php
@@ -149,15 +149,17 @@ class AjaxController extends AbstractBase
      * Support method for getItemStatuses() -- filter suppressed locations from the
      * array of item information for a particular bib record.
      *
      * @param array $record Information on items linked to a single bib record
      *
      * @return array        Filtered version of $record
      */
-    protected function filterSuppressedLocations($record)
+    protected function filterSuppressedLocations($record, $catalog)
     {
         static $hideHoldings = false;
         if ($hideHoldings === false) {
-            $logic = new \VuFind\ILS\Logic\Holds($this->getAuthManager());
+            $logic = new \VuFind\ILS\Logic\Holds($this->getAuthManager(), $catalog);
             $hideHoldings = $logic->getSuppressedLocations();
         }
 
@@ -221,7 +223,7 @@ class AjaxController extends AbstractBase
         $statuses = array();
         foreach ($results as $recordNumber=>$record) {
             // Filter out suppressed locations:
-            $record = $this->filterSuppressedLocations($record);
+            $record = $this->filterSuppressedLocations($record, $catalog);
 
             // Skip empty records:
             if (count($record)) {
@@ -149,15 +149,17 @@ class AjaxController extends AbstractBase
      * array of item information for a particular bib record.
      *
-     * @param array $record Information on items linked to a single bib record
+     * @param array                  $record  Information on items linked to a single
+     * bib record
+     * @param \VuFind\ILS\Connection $catalog ILS connection
      *
      * @return array        Filtered version of $record